//-----------------------------------------------------------------------------
// Clouds.fx
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//
// With color parametrization by Julien Villers :-)
//-----------------------------------------------------------------------------


// the relative position for the texture coordinates, inducing a slight parallax
float2 Position;
float3 ColorRatios;

// modify the sampler state on the zero texture sampler, used by SpriteBatch
sampler TextureSampler : register(s0) = 
sampler_state
{
    AddressU = Wrap;
    AddressV = Wrap;
};


float4 PixelShaderFunction(float2 texCoord : TEXCOORD0) : COLOR0
{
	float2 coord = texCoord;
	static const float3 ratios = { 0.5f, 0.3f, 0.1f};
	int3 ranks = {0, 0, 0};

	// Compute rank for each color. TODO: [OPTI] There should be a better way, those are arrays...
	if (ColorRatios.g > ColorRatios.r)
		ranks[0]++;
	else 
		ranks[1]++;
	
	if (ColorRatios.b > ColorRatios.r)
		ranks[0]++;
	else
		ranks[2]++;
	
	if (ColorRatios.b > ColorRatios.g)
		ranks[1]++;
	else
		ranks[2]++;

    // sample from the cloud texture for the red component
    coord.x += Position.x * 0.00025f - 0.25f;
    coord.y += Position.y * 0.00025f + 0.15;
    coord *= ratios[ranks.r];
    float4 results = float4(ColorRatios.r,0,0, ColorRatios.r / 4.0f) * tex2D(TextureSampler, coord);

	coord = texCoord;

    // sample from the cloud texture for the green component
    coord.x += Position.x * 0.00025f + 0.25f;
    coord.y += Position.y * 0.00025f - 0.15;
    coord *= ratios[ranks.g];
    results += float4(0,ColorRatios.g,0, ColorRatios.g / 4.0f) * tex2D(TextureSampler, coord);
        
    coord = texCoord;
        
    // sample from the cloud texture for the blue component
    coord.x += Position.x * 0.00025f;
    coord.y += Position.y * 0.00025f;
    coord *= ratios[ranks.b];
    results += float4(0,0,ColorRatios.b, ColorRatios.b / 4.0f) * tex2D(TextureSampler, coord);

    return results;
}


technique Technique1
{
    pass Pass1
    {
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}